awards

# XMLRésuméLibrary: User Guide

award | Element Reference | birth

## Name

awards — Container for one or more awards

## Synopsis

### Content Model

    (title?,award+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `awards` element contains one or more `award`s.

### Parents

`awards` may be contained in these elements: `resume`

## Examples

    <awards>
      <title>Awards and Honors</title>
      <award>
        <title>Employee of the Month</title>
        <organization>ACME, Inc.</organization>
        <date><month>May</month><year>2002</year></date>
        <description>
          <para>
            Received for <emphasis>exceptional</emphasis> customer service.
          </para>
        </description>
      </award>
      <award>
        <title>AP Scholar</title>
        <organization>College Board</organization>
        <date><year>2002</year></date>
      </award>
    </awards>

award | Element Reference | birth